function out = log_merge(in,opt)

% log_merge - merge logs into single log
% --------------------------------------
%
% opt = log_merge
%
% out = log_merge(in,opt)
%
% Input:
% ------
%  in - logs to merge
%  opt - merge options
%
% Output:
% -------
%  out - merged log